import { Diagnostic as DiagnosticType, Position as PositionType, CompletionItem as CompletionItemType } from 'vscode-languageserver-protocol';
import { GraphQLSchema, KindEnum } from 'graphql';
import { ASTNode, DocumentNode, FragmentDefinitionNode, NamedTypeNode, TypeDefinitionNode, NameNode } from 'graphql/language';
import { GraphQLArgument, GraphQLEnumValue, GraphQLField, GraphQLInputFieldMap, GraphQLType } from 'graphql/type/definition';
import { GraphQLDirective } from 'graphql/type/directives';
export declare type Maybe<T> = T | null | undefined;
export { GraphQLConfig, GraphQLProjectConfig };
import { GraphQLConfig, GraphQLProjectConfig } from 'graphql-config';
export declare type TokenPattern = string | ((char: string) => boolean) | RegExp;
export interface CharacterStream {
    getStartOfToken: () => number;
    getCurrentPosition: () => number;
    eol: () => boolean;
    sol: () => boolean;
    peek: () => string | null;
    next: () => string;
    eat: (pattern: TokenPattern) => string | undefined;
    eatWhile: (match: TokenPattern) => boolean;
    eatSpace: () => boolean;
    skipToEnd: () => void;
    skipTo: (position: number) => void;
    match: (pattern: TokenPattern, consume?: Maybe<boolean>, caseFold?: Maybe<boolean>) => string[] | boolean;
    backUp: (num: number) => void;
    column: () => number;
    indentation: () => number;
    current: () => string;
}
export declare type GraphQLConfiguration = GraphQLProjectConfiguration & {
    projects?: {
        [projectName: string]: GraphQLProjectConfiguration;
    };
};
export declare type GraphQLProjectConfiguration = {
    name?: string;
    schemaPath?: string;
    includes?: string[];
    excludes?: string[];
    extensions?: GraphQLConfigurationExtension;
};
export declare type GraphQLConfigurationExtension = {
    [name: string]: unknown;
};
export interface GraphQLCache {
    getGraphQLConfig: () => GraphQLConfig;
    getObjectTypeDependencies: (query: string, fragmentDefinitions: Map<string, ObjectTypeInfo>) => Promise<ObjectTypeInfo[]>;
    getObjectTypeDependenciesForAST: (parsedQuery: ASTNode, fragmentDefinitions: Map<string, ObjectTypeInfo>) => Promise<ObjectTypeInfo[]>;
    getObjectTypeDefinitions: (graphQLConfig: GraphQLProjectConfig) => Promise<Map<string, ObjectTypeInfo>>;
    updateObjectTypeDefinition: (rootDir: Uri, filePath: Uri, contents: CachedContent[]) => Promise<void>;
    updateObjectTypeDefinitionCache: (rootDir: Uri, filePath: Uri, exists: boolean) => Promise<void>;
    getFragmentDependencies: (query: string, fragmentDefinitions: Maybe<Map<string, FragmentInfo>>) => Promise<FragmentInfo[]>;
    getFragmentDependenciesForAST: (parsedQuery: ASTNode, fragmentDefinitions: Map<string, FragmentInfo>) => Promise<FragmentInfo[]>;
    getFragmentDefinitions: (graphQLConfig: GraphQLProjectConfig) => Promise<Map<string, FragmentInfo>>;
    updateFragmentDefinition: (rootDir: Uri, filePath: Uri, contents: CachedContent[]) => Promise<void>;
    updateFragmentDefinitionCache: (rootDir: Uri, filePath: Uri, exists: boolean) => Promise<void>;
    getSchema: (appName?: string, queryHasExtensions?: boolean) => Promise<GraphQLSchema | null>;
}
export declare type Position = PositionType & {
    line: number;
    character: number;
    lessThanOrEqualTo?: (position: Position) => boolean;
};
export interface Range {
    start: Position;
    end: Position;
    containsPosition: (position: Position) => boolean;
}
export declare type CachedContent = {
    query: string;
    range: Range | null;
};
export declare type RuleOrString = Rule | string;
export declare type ParseRule = RuleOrString[] | ((token: Token, stream: CharacterStream) => string | null | void);
export declare type Token = {
    kind: string;
    value: string;
};
export declare type Rule = {
    style?: string;
    match?: (token: Token) => boolean;
    update?: (state: State, token: Token) => void;
    separator?: string | Rule;
    isList?: boolean;
    ofRule?: Rule | string;
};
export declare type RuleKind = KindEnum | 'AliasedField' | 'Arguments' | 'ShortQuery' | 'Query' | 'Mutation' | 'Subscription' | 'TypeCondition' | 'Invalid' | 'Comment' | 'SchemaDef' | 'ScalarDef' | 'ObjectTypeDef' | 'InterfaceDef' | 'UnionDef' | 'EnumDef' | 'FieldDef' | 'InputDef' | 'InputValueDef' | 'ArgumentsDef' | 'ExtendDef' | 'DirectiveDef';
export declare type State = {
    level: number;
    levels?: number[];
    prevState: Maybe<State>;
    rule: Maybe<ParseRule>;
    kind: Maybe<RuleKind>;
    name: Maybe<string>;
    type: Maybe<string>;
    step: number;
    needsSeperator: boolean;
    needsAdvance?: boolean;
    indentLevel?: number;
};
export declare type Uri = string;
export declare type GraphQLFileMetadata = {
    filePath: Uri;
    size: number;
    mtime: number;
};
export declare type GraphQLFileInfo = {
    filePath: Uri;
    content: string;
    asts: DocumentNode[];
    queries: CachedContent[];
    size: number;
    mtime: number;
};
export declare type ContextToken = {
    start: number;
    end: number;
    string: string;
    state: State;
    style: string;
};
export declare type ContextTokenForCodeMirror = {
    start: number;
    end: number;
    string: string;
    type: string | null;
    state: State;
};
export declare type ContextTokenUnion = ContextToken | ContextTokenForCodeMirror;
export declare type AllTypeInfo = {
    type: Maybe<GraphQLType>;
    parentType: Maybe<GraphQLType>;
    inputType: Maybe<GraphQLType>;
    directiveDef: Maybe<GraphQLDirective>;
    fieldDef: Maybe<GraphQLField<any, any>>;
    enumValue: Maybe<GraphQLEnumValue>;
    argDef: Maybe<GraphQLArgument>;
    argDefs: Maybe<GraphQLArgument[]>;
    objectFieldDefs: Maybe<GraphQLInputFieldMap>;
};
export declare type FragmentInfo = {
    filePath?: Uri;
    content: string;
    definition: FragmentDefinitionNode;
};
export declare type NamedTypeInfo = {
    filePath?: Uri;
    content: string;
    definition: NamedTypeNode;
};
export declare type ObjectTypeInfo = {
    filePath?: Uri;
    content: string;
    definition: TypeDefinitionNode;
};
export declare type Diagnostic = DiagnosticType;
export declare type CompletionItemBase = {
    label: string;
    isDeprecated?: boolean;
};
export declare type CompletionItem = CompletionItemType & {
    isDeprecated?: boolean;
    deprecationReason?: Maybe<string>;
};
export declare type CompletionItemForCodeMirror = {
    label: string;
    type?: GraphQLType;
    documentation: string | null | undefined;
    isDeprecated?: boolean;
    deprecationReason: string | null | undefined;
};
export declare type Definition = {
    path: Uri;
    position: Position;
    range?: Range;
    id?: string;
    name?: string;
    language?: string;
    projectRoot?: Uri;
};
export declare type DefinitionQueryResult = {
    queryRange: Range[];
    definitions: Definition[];
};
export declare type TokenKind = 'keyword' | 'class-name' | 'constructor' | 'method' | 'param' | 'string' | 'whitespace' | 'plain' | 'type';
export declare type TextToken = {
    kind: TokenKind;
    value: string | NameNode;
};
export declare type TokenizedText = TextToken[];
export declare type OutlineTree = {
    plainText?: string;
    tokenizedText?: TokenizedText;
    representativeName?: string;
    kind: string;
    startPosition: Position;
    endPosition?: Position;
    children: OutlineTree[];
};
export declare type Outline = {
    outlineTrees: OutlineTree[];
};
export interface FileEvent {
    uri: string;
    type: FileChangeType;
}
export declare const FileChangeTypeKind: {
    Created: number;
    Changed: number;
    Deleted: number;
};
export declare type FileChangeTypeKind = {
    Created: 1;
    Changed: 2;
    Deleted: 3;
};
export declare type FileChangeTypeKeys = keyof FileChangeTypeKind;
export declare type FileChangeType = FileChangeTypeKind[FileChangeTypeKeys];
//# sourceMappingURL=index.d.ts.map